@@ -70,7 +70,8 @@ def _to_event(rule):
                 rule['publish']({
                         **pick(rule,[
                             'logger',
-                            'bus_name'
+                            'bus_name',
+                            'source'
                         ]),
                         'max_batch_size': 1,
                         'event_field': 'emit'
